package com.boco.nbd.wios.downloadfile.controller;

import cn.hutool.core.util.ObjectUtil;
import com.boco.nbd.wios.manage.entity.bo.Order;
import com.boco.nbd.wios.manage.entity.vo.WallboxApplyExcelVO;
import com.boco.nbd.wios.manage.mapper.def.OrderDao;
import com.boco.nbd.wios.manage.service.impl.WallboxApplyService;
import com.boco.nbd.wios.utils.ExcelUtils;
import com.ihidea.component.api.v2.BaseResponse;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.ConstraintViolation;
import javax.validation.Validator;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@RestController
public class ImportControllerV2 {

    @Autowired
    private Validator validator;
    @Autowired
    private WallboxApplyService wallboxApplyService;
    @Autowired
    private OrderDao orderDao;

    @PostMapping("/wallbox-apply/import")
    @ApiOperation("导入墙盒申请")
    public BaseResponse<List<WallboxApplyExcelVO>> importExcel(@RequestParam(value = "file") MultipartFile file
    ) throws Exception {
        List<WallboxApplyExcelVO> list = ExcelUtils.read(file, WallboxApplyExcelVO.class);

        for (WallboxApplyExcelVO vo : list) {
            Set<ConstraintViolation<WallboxApplyExcelVO>> violations = validator.validate(vo, CreateEntityGroup
                    .class);
            if (!violations.isEmpty()) {
                String errorMessage = violations.stream()
                        .map(ConstraintViolation::getMessage)
                        .collect(Collectors.joining(";"));
                vo.setErrorMessage(errorMessage);
            }

            if (StringUtils.isNotBlank(vo.getOrderId())){
                Order order = orderDao.selectById(vo.getOrderId());
                if (ObjectUtil.isNull(order)) {
                    vo.setErrorMessage("不存在安装订单号");
                }
                if (ObjectUtil.isNotNull(order)) {
                    vo.setWallboxModel(order.getWallboxModel());
                }
                if (ObjectUtil.isNotNull(wallboxApplyService.selectWallboxDetail(vo.getOrderId()))) {
                    vo.setErrorMessage("重复订单申请");
                }
            }
        }
        return new BaseResponse<>(list);
    }

}
